@@ -26,26 +26,27 @@ require_once dirname(__FILE__).'/include/graphs.inc.php';
 
 $page['title'] = _('Custom graphs');
 $page['file'] = 'charts.php';
-$page['scripts'] = ['class.calendar.js', 'gtlc.js', 'flickerfreescreen.js'];
+$page['scripts'] = ['class.calendar.js', 'gtlc.js', 'flickerfreescreen.js', 'layout.mode.js'];
 $page['type'] = detect_page_type(PAGE_TYPE_HTML);
 
-define('ZBX_PAGE_DO_JS_REFRESH', 1);
+CView::$has_web_layout_mode = true;
+$page['web_layout_mode'] = CView::getLayoutMode();
 
-ob_start();
+define('ZBX_PAGE_DO_JS_REFRESH', 1);
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'groupid' =>	[T_ZBX_INT, O_OPT, P_SYS, DB_ID,		null],
-	'hostid' =>		[T_ZBX_INT, O_OPT, P_SYS, DB_ID,		null],
-	'graphid' =>	[T_ZBX_INT, O_OPT, P_SYS, DB_ID,		null],
-	'period' =>		[T_ZBX_INT, O_OPT, P_SYS, null,		null],
-	'stime' =>		[T_ZBX_STR, O_OPT, P_SYS, null,		null],
-	'isNow' =>		[T_ZBX_INT, O_OPT, null,  IN('0,1'),	null],
-	'fullscreen' =>	[T_ZBX_INT, O_OPT, P_SYS, IN('0,1'),	null]
+	'groupid' =>	[T_ZBX_INT,			O_OPT, P_SYS, DB_ID,		null],
+	'hostid' =>		[T_ZBX_INT,			O_OPT, P_SYS, DB_ID,		null],
+	'graphid' =>	[T_ZBX_INT,			O_OPT, P_SYS, DB_ID,		null],
+	'from' =>		[T_ZBX_RANGE_TIME,	O_OPT, P_SYS, null,			null],
+	'to' =>			[T_ZBX_RANGE_TIME,	O_OPT, P_SYS, null,			null],
+	'action' =>		[T_ZBX_STR,			O_OPT, P_SYS, IN('"'.HISTORY_GRAPH.'","'.HISTORY_VALUES.'"'), null]
 ];
 check_fields($fields);
+validateTimeSelectorPeriod(getRequest('from'), getRequest('to'));
 
 /*
  * Permissions
@@ -66,6 +67,11 @@ if (getRequest('graphid')) {
 	}
 }
 
+if ($page['type'] == PAGE_TYPE_JS || $page['type'] == PAGE_TYPE_HTML_BLOCK) {
+	require_once dirname(__FILE__).'/include/page_footer.php';
+	exit;
+}
+
 $pageFilter = new CPageFilter([
 	'groups' => ['real_hosts' => true, 'with_graphs' => true],
 	'hosts' => ['with_graphs' => true],
@@ -75,44 +81,27 @@ $pageFilter = new CPageFilter([
 	'graphid' => getRequest('graphid')
 ]);
 
-if (hasRequest('period') || hasRequest('stime') || hasRequest('isNow')) {
-	calculateTime([
-		'profileIdx' => 'web.graphs',
-		'profileIdx2' => $pageFilter->graphid,
-		'updateProfile' => true,
-		'period' => getRequest('period'),
-		'stime' => getRequest('stime'),
-		'isNow' => getRequest('isNow')
-	]);
-
-	$curl = (new CUrl())
-		->removeArgument('period')
-		->removeArgument('stime')
-		->removeArgument('isNow');
-
-	ob_end_clean();
-
-	DBstart();
-	CProfile::flush();
-	DBend();
-
-	redirect($curl->getUrl());
-}
-
-ob_end_flush();
-
-if ($page['type'] == PAGE_TYPE_JS || $page['type'] == PAGE_TYPE_HTML_BLOCK) {
-	require_once dirname(__FILE__).'/include/page_footer.php';
-	exit;
-}
-
 /*
  * Display
  */
+$timeselector_options = [
+	'profileIdx' => 'web.graphs.filter',
+	'profileIdx2' => $pageFilter->graphid,
+	'from' => getRequest('from'),
+	'to' => getRequest('to')
+];
+updateTimeSelectorPeriod($timeselector_options);
+
 $data = [
 	'pageFilter' => $pageFilter,
 	'graphid' => $pageFilter->graphid,
-	'fullscreen' => $_REQUEST['fullscreen']
+	'action' => getRequest('action', HISTORY_GRAPH),
+	'actions' => [
+		HISTORY_GRAPH => _('Graph'),
+		HISTORY_VALUES => _('Values')
+	],
+	'timeline' => getTimeSelectorPeriod($timeselector_options),
+	'active_tab' => CProfile::get('web.graphs.filter.active', 1)
 ];
 
 // render view
