@@ -57,22 +57,47 @@ class CAudit {
 		];
 
 		switch ($resourcetype) {
+			case AUDIT_RESOURCE_ACTION:
+				$field_name_resourceid = 'actionid';
+				$field_name_resourcename = 'name';
+				$table_name = 'actions';
+				break;
+
 			case AUDIT_RESOURCE_APPLICATION:
 				$field_name_resourceid = 'applicationid';
 				$field_name_resourcename = 'name';
 				$table_name = 'applications';
 				break;
 
+			case AUDIT_RESOURCE_CORRELATION:
+				$field_name_resourceid = 'correlationid';
+				$field_name_resourcename = 'name';
+				$table_name = 'correlation';
+				break;
+
 			case AUDIT_RESOURCE_DASHBOARD:
 				$field_name_resourceid = 'dashboardid';
 				$field_name_resourcename = 'name';
 				$table_name = 'dashboard';
 				break;
 
-			case AUDIT_RESOURCE_ICON_MAP:
-				$field_name_resourceid = 'iconmapid';
+			case AUDIT_RESOURCE_DISCOVERY_RULE:
+				$field_name_resourceid = 'druleid';
 				$field_name_resourcename = 'name';
-				$table_name = 'icon_map';
+				$table_name = 'drules';
+				break;
+
+			case AUDIT_RESOURCE_GRAPH:
+			case AUDIT_RESOURCE_GRAPH_PROTOTYPE:
+				$field_name_resourceid = 'graphid';
+				$field_name_resourcename = 'name';
+				$table_name = 'graphs';
+				break;
+
+			case AUDIT_RESOURCE_HOST_PROTOTYPE:
+				$field_name_resourceid = 'hostid';
+				$field_name_resourcename = 'host';
+				$table_name = 'hosts';
 				break;
 
 			case AUDIT_RESOURCE_HOST_GROUP:
@@ -81,18 +106,50 @@ class CAudit {
 				$table_name = 'groups';
 				break;
 
+			case AUDIT_RESOURCE_ICON_MAP:
+				$field_name_resourceid = 'iconmapid';
+				$field_name_resourcename = 'name';
+				$table_name = 'icon_map';
+				break;
+
+			case AUDIT_RESOURCE_ITEM:
+			case AUDIT_RESOURCE_ITEM_PROTOTYPE:
+				$field_name_resourceid = 'itemid';
+				$field_name_resourcename = 'name';
+				$table_name = 'items';
+				break;
+
 			case AUDIT_RESOURCE_MACRO:
 				$field_name_resourceid = 'globalmacroid';
 				$field_name_resourcename = 'macro';
 				$table_name = 'globalmacro';
 				break;
 
+			case AUDIT_RESOURCE_PROXY:
+				$field_name_resourceid = 'proxyid';
+				$field_name_resourcename = 'host';
+				$table_name = 'hosts';
+				break;
+
+			case AUDIT_RESOURCE_SCENARIO:
+				$field_name_resourceid = 'httptestid';
+				$field_name_resourcename = 'name';
+				$table_name = 'httptest';
+				break;
+
 			case AUDIT_RESOURCE_SCRIPT:
 				$field_name_resourceid = 'scriptid';
 				$field_name_resourcename = 'name';
 				$table_name = 'scripts';
 				break;
 
+			case AUDIT_RESOURCE_TRIGGER:
+			case AUDIT_RESOURCE_TRIGGER_PROTOTYPE:
+				$field_name_resourceid = 'triggerid';
+				$field_name_resourcename = 'description';
+				$table_name = 'triggers';
+				break;
+
 			case AUDIT_RESOURCE_USER:
 				$field_name_resourceid = 'userid';
 				$field_name_resourcename = 'alias';
@@ -111,12 +168,6 @@ class CAudit {
 				$table_name = 'valuemaps';
 				break;
 
-			case AUDIT_RESOURCE_SCENARIO:
-				$field_name_resourceid = 'httptestid';
-				$field_name_resourcename = 'name';
-				$table_name = 'httptest';
-				break;
-
 			default:
 				return;
 		}
