@@ -158,168 +158,6 @@ class CHistoryManager {
 		return $results;
 	}
 
-	/**
-	 * Returns the history value of the item at the given time. If no value exists at the given time, the function
-	 * will return the previous value.
-	 *
-	 * The $item parameter must have the value_type and itemid properties set.
-	 *
-	 * @param array $item     item to get value for
-	 * @param int   $clock    timestamp (seconds)
-	 * @param int   $ns       timestamp (nanoseconds)
-	 *
-	 * @return string    value at specified time of first value before specified time
-	 */
-	public function getValueAt($item, $clock, $ns) {
-		switch (self::getDataSourceType($item['value_type'])) {
-			case ZBX_HISTORY_SOURCE_ELASTIC:
-				return $this->getValueAtFromElasticsearch($item, $clock, $ns);
-
-			default:
-				return $this->getValueAtFromSql($item, $clock, $ns);
-		}
-	}
-
-	/**
-	 * Elasticsearch specific implementation of getValueAt.
-	 *
-	 * @see CHistoryManager::getValueAt
-	 */
-	private function getValueAtFromElasticsearch($item, $clock, $ns) {
-		$query = [
-			'sort' => [
-				'clock' => ZBX_SORT_DOWN,
-				'ns' => ZBX_SORT_DOWN
-			],
-			'size' => 1
-		];
-
-		$filters = [
-			[
-				[
-					'term' => [
-						'itemid' => $item['itemid']
-					]
-				],
-				[
-					'term' => [
-						'clock' => $clock
-					]
-				],
-				[
-					'range' => [
-						'ns' => [
-							'lte' => $ns
-						]
-					]
-				]
-			],
-			[
-				[
-					'term' => [
-						'itemid' => $item['itemid']
-					]
-				],
-				[
-					'range' => [
-						'clock' => [
-							'lt' => $clock
-						] + (ZBX_HISTORY_PERIOD ? ['gte' => $clock - ZBX_HISTORY_PERIOD] : [])
-					]
-				]
-			]
-		];
-
-		foreach ($filters as $filter) {
-			$query['query']['bool']['must'] = $filter;
-			$endpoints = self::getElasticsearchEndpoints($item['value_type']);
-
-			if (count($endpoints) !== 1) {
-				break;
-			}
-
-			$result = CElasticsearchHelper::query('POST', reset($endpoints), $query);
-
-			if (count($result) === 1 && is_array($result[0]) && array_key_exists('value', $result[0])) {
-				return $result[0]['value'];
-			}
-		}
-
-		return null;
-	}
-
-	/**
-	 * SQL specific implementation of getValueAt.
-	 *
-	 * @see CHistoryManager::getValueAt
-	 */
-	private function getValueAtFromSql($item, $clock, $ns) {
-		$value = null;
-		$table = self::getTableName($item['value_type']);
-
-		$sql = 'SELECT value'.
-				' FROM '.$table.
-				' WHERE itemid='.zbx_dbstr($item['itemid']).
-					' AND clock='.zbx_dbstr($clock).
-					' AND ns='.zbx_dbstr($ns);
-
-		if (($row = DBfetch(DBselect($sql, 1))) !== false) {
-			$value = $row['value'];
-		}
-
-		if ($value !== null) {
-			return $value;
-		}
-
-		$max_clock = 0;
-		$sql = 'SELECT DISTINCT clock'.
-				' FROM '.$table.
-				' WHERE itemid='.zbx_dbstr($item['itemid']).
-					' AND clock='.zbx_dbstr($clock).
-					' AND ns<'.zbx_dbstr($ns);
-
-		if (($row = DBfetch(DBselect($sql))) !== false) {
-			$max_clock = $row['clock'];
-		}
-
-		if ($max_clock == 0) {
-			$sql = 'SELECT MAX(clock) AS clock'.
-					' FROM '.$table.
-					' WHERE itemid='.zbx_dbstr($item['itemid']).
-						' AND clock<'.zbx_dbstr($clock).
-						(ZBX_HISTORY_PERIOD ? ' AND clock>='.zbx_dbstr($clock - ZBX_HISTORY_PERIOD) : '');
-
-			if (($row = DBfetch(DBselect($sql))) !== false) {
-				$max_clock = $row['clock'];
-			}
-		}
-
-		if ($max_clock == 0) {
-			return $value;
-		}
-
-		if ($clock == $max_clock) {
-			$sql = 'SELECT value'.
-					' FROM '.$table.
-					' WHERE itemid='.zbx_dbstr($item['itemid']).
-						' AND clock='.zbx_dbstr($clock).
-						' AND ns<'.zbx_dbstr($ns);
-		}
-		else {
-			$sql = 'SELECT value'.
-					' FROM '.$table.
-					' WHERE itemid='.zbx_dbstr($item['itemid']).
-						' AND clock='.zbx_dbstr($max_clock).
-					' ORDER BY itemid,clock desc,ns desc';
-		}
-
-		if (($row = DBfetch(DBselect($sql, 1))) !== false) {
-			$value = $row['value'];
-		}
-
-		return $value;
-	}
-
 	/**
 	 * Returns history value aggregation for graphs.
 	 *
@@ -663,177 +501,6 @@ class CHistoryManager {
 		return null;
 	}
 
-	/**
-	 * Return the time of the 1st appearance of items in history or trends.
-	 *
-	 * @param array $items
-	 * @param array $items[]['itemid']
-	 * @param array $items[]['hostid']
-	 * @param array $items[]['value_type']
-	 * @param array $items[]['history']
-	 * @param array $items[]['trends']
-	 *
-	 * @return int    timestamp (unixtime)
-	 */
-	public function getMinClock(array $items) {
-		$item_types = [
-			ITEM_VALUE_TYPE_FLOAT => [],
-			ITEM_VALUE_TYPE_STR => [],
-			ITEM_VALUE_TYPE_LOG => [],
-			ITEM_VALUE_TYPE_UINT64 => [],
-			ITEM_VALUE_TYPE_TEXT => []
-		];
-		$max = ['history' => 0, 'trends' => 0];
-		$simple_interval_parser = new CSimpleIntervalParser();
-
-		$items = CMacrosResolverHelper::resolveTimeUnitMacros($items, ['history', 'trends']);
-
-		foreach ($items as $item) {
-			$item_types[$item['value_type']][] = $item['itemid'];
-
-			if ($item['value_type'] == ITEM_VALUE_TYPE_FLOAT || $item['value_type'] == ITEM_VALUE_TYPE_UINT64) {
-				if ($simple_interval_parser->parse($item['history']) == CParser::PARSE_SUCCESS) {
-					$item['history'] = (int) timeUnitToSeconds($item['history']);
-					$max['history'] = max($max['history'], $item['history']);
-				}
-
-				if ($simple_interval_parser->parse($item['trends']) == CParser::PARSE_SUCCESS) {
-					$item['trends'] = (int) timeUnitToSeconds($item['trends']);
-					$max['trends'] = max($max['trends'], $item['trends']);
-				}
-			}
-		}
-
-		$source = ($max['history'] > $max['trends']) ? 'history' : 'trends';
-		$storage_items = [];
-
-		foreach ($item_types as $type => $itemids) {
-			if (!$itemids) {
-				continue;
-			}
-
-			$history_source = self::getDataSourceType($type);
-			$storage_items[$history_source][$type] = $itemids;
-		}
-
-		$min_clock = [];
-
-		if (array_key_exists(ZBX_HISTORY_SOURCE_ELASTIC, $storage_items)) {
-			$min_clock[] = $this->getMinClockFromElasticsearch($storage_items[ZBX_HISTORY_SOURCE_ELASTIC]);
-		}
-
-		if (array_key_exists(ZBX_HISTORY_SOURCE_SQL, $storage_items)) {
-			$min_clock[] = $this->getMinClockFromSql($storage_items[ZBX_HISTORY_SOURCE_SQL], $source);
-		}
-
-		$min_clock = min($min_clock);
-
-		// If DB clock column is corrupted having negative numbers, return min clock from max possible history storage.
-		if ($min_clock == 0) {
-			if ($item_types[ITEM_VALUE_TYPE_FLOAT] || $item_types[ITEM_VALUE_TYPE_UINT64]) {
-				$min_clock = time() - max($max['history'], $max['trends']);
-
-				/*
-				 * In case history storage exceeds the maximum time difference between current year and minimum 1970
-				 * (for example year 2014 - 200 years < year 1970), correct year to 1970 (unix time timestamp 0).
-				 */
-				if ($min_clock < 0) {
-					$min_clock = 0;
-				}
-			}
-			else {
-				$min_clock = time() - SEC_PER_YEAR;
-			}
-		}
-
-		return $min_clock;
-	}
-
-	/**
-	 * Elasticsearch specific implementation of getMinClock.
-	 *
-	 * @see CHistoryManager::getMinClock
-	 */
-	private function getMinClockFromElasticsearch(array $items) {
-		$query = [
-			'aggs'=> [
-				'min_clock' => [
-					'min' => [
-						'field' => 'clock'
-					]
-				]
-			],
-			'size'=> 0
-		];
-
-		$min_clock = [];
-
-		foreach (self::getElasticsearchEndpoints(array_keys($items)) as $type => $endpoint) {
-			$query['query']['terms']['itemid'] = $items[$type];
-			$data = CElasticsearchHelper::query('POST', $endpoint, $query);
-
-			// Field value_as_string is used as a workaround for date aggregation being presented as milliseconds.
-			if (array_key_exists('min_clock', $data) && array_key_exists('value_as_string', $data['min_clock'])) {
-				$min_clock[] = $data['min_clock']['value_as_string'];
-			}
-		}
-
-		if ($min_clock) {
-			return min($min_clock);
-		}
-
-		return null;
-	}
-
-	/**
-	 * SQL specific implementation of getMinClock.
-	 *
-	 * @see CHistoryManager::getMinClock
-	 */
-	private function getMinClockFromSql(array $items, $source) {
-		$sql_unions = [];
-
-		foreach ($items as $type => $itemids) {
-			if (!$itemids) {
-				continue;
-			}
-
-			switch ($type) {
-				case ITEM_VALUE_TYPE_FLOAT:
-					$sql_from = $source;
-					break;
-				case ITEM_VALUE_TYPE_STR:
-					$sql_from = 'history_str';
-					break;
-				case ITEM_VALUE_TYPE_LOG:
-					$sql_from = 'history_log';
-					break;
-				case ITEM_VALUE_TYPE_UINT64:
-					$sql_from = $source.'_uint';
-					break;
-				case ITEM_VALUE_TYPE_TEXT:
-					$sql_from = 'history_text';
-					break;
-				default:
-					$sql_from = 'history';
-			}
-
-			foreach ($itemids as $itemid) {
-				$sql_unions[] =
-					'SELECT MIN(h.clock) AS clock'.
-					' FROM '.$sql_from.' h'.
-					' WHERE h.itemid='.zbx_dbstr($itemid);
-			}
-		}
-
-		$row = DBfetch(DBselect(
-			'SELECT MIN(h.clock) AS min_clock'.
-			' FROM ('.implode(' UNION ALL ', $sql_unions).') h'
-		));
-
-		return $row['min_clock'];
-	}
-
 	/**
 	 * Clear item history and trends by provided item IDs. History is deleted from both SQL and Elasticsearch.
 	 *
@@ -1032,7 +699,7 @@ class CHistoryManager {
 
 		foreach ($indices as $type => $index) {
 			if (($url = self::getElasticsearchUrl($index)) !== null) {
-				$endponts[$type] = $url.$index.'/values/'.$action;
+				$endponts[$type] = $url.$index.'*/values/'.$action;
 			}
 		}
 
