@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -530,69 +530,51 @@ class CGraphPrototype extends CGraphGeneral {
 	 * Delete GraphPrototype.
 	 *
 	 * @param array $graphids
-	 * @param bool  $nopermissions
 	 *
 	 * @return array
 	 */
-	public function delete(array $graphids, $nopermissions = false) {
-		if (empty($graphids)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+	public function delete(array $graphids) {
+		$this->validateDelete($graphids, $db_graphs);
+
+		CGraphPrototypeManager::delete($graphids);
+
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_GRAPH_PROTOTYPE, $db_graphs);
+
+		return ['graphids' => $graphids];
+	}
+
+	/**
+	 * Validates the input parameters for the delete() method.
+	 *
+	 * @param array $graphids   [IN/OUT]
+	 * @param array $db_graphs  [OUT]
+	 *
+	 * @throws APIException if the input is invalid.
+	 */
+	private function validateDelete(array &$graphids, array &$db_graphs = null) {
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $graphids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		$delGraphs = $this->get([
+		$db_graphs = $this->get([
+			'output' => ['graphid', 'name', 'templateid'],
 			'graphids' => $graphids,
 			'editable' => true,
-			'output' => API_OUTPUT_EXTEND,
 			'preservekeys' => true
 		]);
 
-		if (!$nopermissions) {
-			foreach ($graphids as $graphid) {
-				if (!isset($delGraphs[$graphid])) {
-					self::exception(ZBX_API_ERROR_PERMISSIONS, _('You do not have permission to perform this operation.'));
-				}
-				if ($delGraphs[$graphid]['templateid'] != 0) {
-					self::exception(ZBX_API_ERROR_PERMISSIONS, _('Cannot delete templated graphs.'));
-				}
+		foreach ($graphids as $graphid) {
+			if (!array_key_exists($graphid, $db_graphs)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
+
+			if ($db_graphs[$graphid]['templateid'] != 0) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot delete templated graph prototype.'));
 			}
 		}
-
-		$parentGraphids = $graphids;
-		do {
-			$dbGraphs = DBselect('SELECT g.graphid FROM graphs g WHERE '.dbConditionInt('g.templateid', $parentGraphids));
-			$parentGraphids = [];
-			while ($dbGraph = DBfetch($dbGraphs)) {
-				$parentGraphids[] = $dbGraph['graphid'];
-				$graphids[] = $dbGraph['graphid'];
-			}
-		} while (!empty($parentGraphids));
-
-		$graphids = array_unique($graphids);
-		$createdGraphs = [];
-
-		$dbGraphs = DBselect('SELECT gd.graphid FROM graph_discovery gd WHERE '.dbConditionInt('gd.parent_graphid', $graphids));
-		while ($graph = DBfetch($dbGraphs)) {
-			$createdGraphs[$graph['graphid']] = $graph['graphid'];
-		}
-		if (!empty($createdGraphs)) {
-			$result = API::Graph()->delete($createdGraphs, true);
-			if (!$result) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _('Cannot delete graphs created by low level discovery.'));
-			}
-		}
-
-		DB::delete('screens_items', [
-			'resourceid' => $graphids,
-			'resourcetype' => SCREEN_RESOURCE_LLD_GRAPH
-		]);
-
-		DB::delete('graphs', ['graphid' => $graphids]);
-
-		foreach ($delGraphs as $graph) {
-			info(_s('Graph prototype "%s" deleted.', $graph['name']));
-		}
-
-		return ['graphids' => $graphids];
 	}
 
 	protected function createReal($graph) {
