@@ -24,44 +24,46 @@ class CMenuPopupHelper {
 	/**
 	 * Prepare data for item history menu popup.
 	 *
-	 * @param array $item				item data
-	 * @param int   $item['itemid']		item id
-	 * @param int   $item['value_type']	item value type
+	 * @param array $item                Item data.
+	 * @param int   $item['itemid']      Item ID.
+	 * @param int   $item['value_type']  Item value type.
 	 *
 	 * @return array
 	 */
 	public static function getHistory(array $item) {
-		return [
+		$data = [
 			'type' => 'history',
 			'itemid' => $item['itemid'],
 			'hasLatestGraphs' => in_array($item['value_type'], [ITEM_VALUE_TYPE_UINT64, ITEM_VALUE_TYPE_FLOAT])
 		];
+
+		return $data;
 	}
 
 	/**
 	 * Prepare data for host menu popup.
 	 *
-	 * @param array  $host						host data
-	 * @param string $host['hostid']			host id
-	 * @param string $host['status']			host status
-	 * @param array  $host['graphs']			host graphs
-	 * @param array  $host['screens']			host screens
-	 * @param array  $scripts					host scripts (optional)
-	 * @param string $scripts[]['name']			script name
-	 * @param string $scripts[]['scriptid']		script id
-	 * @param string $scripts[]['confirmation']	confirmation text
-	 * @param bool   $hasGoTo					"Go to" block in popup
+	 * @param array  $host                       Host data.
+	 * @param string $host['hostid']             Host ID.
+	 * @param string $host['status']             Host status.
+	 * @param array  $host['graphs']             Host graphs.
+	 * @param array  $host['screens']            Host screens.
+	 * @param array  $scripts                    Host scripts (optional).
+	 * @param string $scripts[]['name']          Script name.
+	 * @param string $scripts[]['scriptid']      Script ID.
+	 * @param string $scripts[]['confirmation']  Confirmation text.
+	 * @param bool   $has_goto                   "Go to" block in popup.
 	 *
 	 * @return array
 	 */
-	public static function getHost(array $host, array $scripts = null, $hasGoTo = true) {
+	public static function getHost(array $host, array $scripts = null, $has_goto = true) {
 		$data = [
 			'type' => 'host',
 			'hostid' => $host['hostid'],
 			'showGraphs' => (bool) $host['graphs'],
 			'showScreens' => (bool) $host['screens'],
 			'showTriggers' => ($host['status'] == HOST_STATUS_MONITORED),
-			'hasGoTo' => $hasGoTo
+			'hasGoTo' => $has_goto
 		];
 
 		if ($scripts) {
@@ -87,28 +89,30 @@ class CMenuPopupHelper {
 	/**
 	 * Prepare data for map menu popup.
 	 *
-	 * @param string $hostId					host id
-	 * @param array  $scripts					host scripts (optional)
-	 * @param string $scripts[]['name']			script name
-	 * @param string $scripts[]['scriptid']		script id
-	 * @param string $scripts[]['confirmation']	confirmation text
-	 * @param array  $gotos						goto links (optional)
-	 * @param array  $gotos['graphs']			link to host graphs page with url parameters ("name" => "value") (optional)
-	 * @param array  $gotos['screens']			link to host screen page with url parameters ("name" => "value") (optional)
-	 * @param array  $gotos['triggerStatus']	link to trigger status page with url parameters ("name" => "value") (optional)
-	 * @param array  $gotos['submap']			link to submap page with url parameters ("name" => "value") (optional)
-	 * @param array  $gotos['events']			link to events page with url parameters ("name" => "value") (optional)
-	 * @param array  $urls						local and global map urls (optional)
-	 * @param string $urls[]['name']			url name
-	 * @param string $urls[]['url']				url
+	 * @param string $hostId                     Host ID.
+	 * @param array  $scripts                    Host scripts.
+	 * @param string $scripts[]['name']          Script name.
+	 * @param string $scripts[]['scriptid']      Script ID.
+	 * @param string $scripts[]['confirmation']  Confirmation text.
+	 * @param array  $gotos                      Enable goto links.
+	 * @param array  $gotos['graphs']            Link to host graphs page with url parameters ("name" => "value") (optional).
+	 * @param array  $gotos['screens']           Link to host screen page with url parameters ("name" => "value") (optional).
+	 * @param array  $gotos['triggerStatus']     Link to "Problems" page with url parameters ("name" => "value") (optional).
+	 * @param array  $gotos['submap']            Link to submap page with url parameters ("name" => "value") (optional).
+	 * @param array  $gotos['events']            Link to events page with url parameters ("name" => "value") (optional).
+	 * @param array  $urls                       Local and global map links (optional).
+	 * @param string $urls[]['name']             Link name.
+	 * @param string $urls[]['url']              Link url.
 	 *
 	 * @return array
 	 */
 	public static function getMap($hostId, array $scripts = null, array $gotos = null, array $urls = null) {
+
 		$data = [
 			'type' => 'map'
 		];
 
+
 		if ($scripts) {
 			foreach ($scripts as &$script) {
 				$script['name'] = trimPath($script['name']);
@@ -166,28 +170,31 @@ class CMenuPopupHelper {
 	/**
 	 * Prepare data for trigger menu popup.
 	 *
-	 * @param array  $trigger							trigger data
-	 * @param string $trigger['triggerid']				trigger ID
-	 * @param int    $trigger['flags']					trigger flags (TRIGGER_FLAG_DISCOVERY*)
-	 * @param array  $trigger['hosts']					hosts, used by trigger expression
-	 * @param string $trigger['hosts'][]['hostid']		host ID
-	 * @param string $trigger['hosts'][]['name']		host name
-	 * @param string $trigger['hosts'][]['status']		host status
-	 * @param array  $trigger['items']					trigger items
-	 * @param string $trigger['items'][]['itemid']		item ID
-	 * @param string $trigger['items'][]['hostid']		host ID
-	 * @param string $trigger['items'][]['name']		item name
-	 * @param string $trigger['items'][]['key_']		item key
-	 * @param string $trigger['items'][]['value_type']	type of information of the item
-	 * @param string $trigger['url']					trigger URL
-	 * @param array  $acknowledge						acknowledge link parameters (optional)
-	 * @param string $acknowledge['eventid']			event ID
-	 * @param string $acknowledge['screenid']			screen ID (optional)
-	 * @param string $acknowledge['backurl']			return URL (optional)
+	 * @param array  $trigger                           Trigger data.
+	 * @param string $trigger['triggerid']              Trigger ID.
+	 * @param int    $trigger['flags']                  Trigger flags (TRIGGER_FLAG_DISCOVERY*).
+	 * @param array  $trigger['hosts']                  Hosts, used by trigger expression.
+	 * @param string $trigger['hosts'][]['hostid']      Host ID.
+	 * @param string $trigger['hosts'][]['name']        Host name.
+	 * @param string $trigger['hosts'][]['status']      Host status.
+	 * @param array  $trigger['items']                  Trigger items.
+	 * @param string $trigger['items'][]['itemid']      Item ID.
+	 * @param string $trigger['items'][]['hostid']      Host ID.
+	 * @param string $trigger['items'][]['name']        Item name.
+	 * @param string $trigger['items'][]['key_']        Item key.
+	 * @param string $trigger['items'][]['value_type']  Type of information of the item.
+	 * @param string $trigger['url']                    Trigger URL.
+	 * @param array  $acknowledge                       Acknowledge link parameters (optional).
+	 * @param string $acknowledge['eventid']            Event ID.
+	 * @param string $acknowledge['screenid']           Screen ID (optional).
+	 * @param string $acknowledge['backurl']            Return URL (optional).
+	 * @param array  $options
+	 * @param bool   $options['show_description']       (optional) default: true
+	 * @param bool   $options['description_enabled']    (optional) default: true
 	 *
 	 * @return array
 	 */
-	public static function getTrigger(array $trigger, array $acknowledge = null) {
+	public static function getTrigger(array $trigger, array $acknowledge = null, array $options = []) {
 		$hosts = [];
 		$showEvents = true;
 
@@ -233,6 +240,13 @@ class CMenuPopupHelper {
 			'configuration' => in_array(CWebUser::$data['type'], [USER_TYPE_ZABBIX_ADMIN, USER_TYPE_SUPER_ADMIN])
 		];
 
+		if (array_key_exists('show_description', $options) && $options['show_description'] === false) {
+			$data['show_description'] = false;
+		}
+		else if (array_key_exists('description_enabled', $options) && $options['description_enabled'] === false) {
+			$data['description_enabled'] = false;
+		}
+
 		if ($acknowledge !== null) {
 			$data['acknowledge'] = $acknowledge;
 		}
@@ -279,16 +293,20 @@ class CMenuPopupHelper {
 	}
 
 	/**
-	 * Prepare data for dependent item popup menu.
+	 * Prepare data for dependent item (or item prototype) popup menu.
 	 *
-	 * @param string $itemid    Item id.
-	 * @param string $hostid    Host id.
-	 * @param string $name      Item name.
+	 * @param string $page        Page name.
+	 * @param string $itemid      Item id.
+	 * @param string $parent      Name of parent object argument (hostid or parent_discoveryid).
+	 * @param string $parentid    Parent object id (host id for hosts or discoveryid for discovery rules)
+	 * @param string $name        Item name.
+	 *
+	 * @return array
 	 */
-	public static function getDependentItem($itemid, $hostid, $name) {
-		$url = (new CUrl('items.php'))
-					->setArgument('form', _('Create item'))->setArgument('type', ITEM_TYPE_DEPENDENT)
-					->setArgument('hostid', $hostid)->setArgument('master_itemid', $itemid)
+	protected static function getDependent($page, $itemid, $parent, $parentid, $name) {
+		$url = (new CUrl($page))
+					->setArgument('form', 'create')->setArgument('type', ITEM_TYPE_DEPENDENT)
+					->setArgument($parent, $parentid)->setArgument('master_itemid', $itemid)
 					->getUrl();
 
 		return [
@@ -300,25 +318,25 @@ class CMenuPopupHelper {
 		];
 	}
 
+	/**
+	 * Prepare data for dependent item popup menu.
+	 *
+	 * @param string $itemid    Item id.
+	 * @param string $hostid    Host id.
+	 * @param string $name      Item name.
+	 */
+	public static function getDependentItem($itemid, $hostid, $name) {
+		return self::getDependent('items.php', $itemid, 'hostid', $hostid, $name);
+	}
+
 	/**
 	 * Prepare data for dependent item prototype popup menu.
 	 *
 	 * @param string $itemid                Item id.
-	 * @param string $parent_discoveryid    Prent discovery rule id.
+	 * @param string $parent_discoveryid    Parent discovery rule id.
 	 * @param string $name                  Item name.
 	 */
 	public static function getDependentItemPrototype($itemid, $parent_discoveryid, $name) {
-		$url = (new CUrl('disc_prototypes.php'))
-					->setArgument('form', _('Create item'))->setArgument('type', ITEM_TYPE_DEPENDENT)
-					->setArgument('parent_discoveryid', $parent_discoveryid)->setArgument('master_itemid', $itemid)
-					->getUrl();
-
-		return [
-			'type' => 'dependent_items',
-			'itemid' => $itemid,
-			'item_name' => $name,
-			'add_label' => _('Create dependent item'),
-			'add_url' => $url
-		];
+		return self::getDependent('disc_prototypes.php', $itemid, 'parent_discoveryid', $parent_discoveryid, $name);
 	}
 }
