@@ -28,8 +28,10 @@ class CRadioButtonList extends CList {
 	private $value;
 	private $orientation;
 	private $enabled;
+	private $readonly;
 	private $values;
 	private $modern;
+	private $autofocused;
 
 	public function __construct($name, $value) {
 		parent::__construct();
@@ -40,6 +42,7 @@ class CRadioButtonList extends CList {
 		$this->enabled = true;
 		$this->values = [];
 		$this->modern = false;
+		$this->readonly = false;
 		$this->setId(zbx_formatDomId($name));
 	}
 
@@ -66,6 +69,12 @@ class CRadioButtonList extends CList {
 		return $this;
 	}
 
+	public function setReadonly($readonly) {
+		$this->readonly = $readonly;
+
+		return $this;
+	}
+
 	public function setModern($modern) {
 		$this->modern = $modern;
 
@@ -83,18 +92,27 @@ class CRadioButtonList extends CList {
 			);
 		}
 
+		if ($this->readonly) {
+			parent::addItem(new CVar($this->name, $this->value, zbx_formatDomId($this->name)));
+		}
+
 		foreach ($this->values as $key => $value) {
 			if ($value['id'] === null) {
 				$value['id'] = zbx_formatDomId($this->name).'_'.$key;
 			}
 
 			$radio = (new CInput('radio', $this->name, $value['value']))
-				->setEnabled($this->enabled)
+				// Read-only for radioboxes is simulated by disabling control and adding CVar with value.
+				->setEnabled($this->enabled && !$this->readonly)
 				->onChange($value['on_change'])
 				->setId($value['id']);
 
 			if ($value['value'] === $this->value) {
 				$radio->setAttribute('checked', 'checked');
+
+				if ($this->autofocused) {
+					$radio->setAttribute('autofocus', 'autofocus');
+				}
 			}
 
 			if ($this->modern) {
@@ -106,6 +124,28 @@ class CRadioButtonList extends CList {
 			}
 		}
 
+		if ($this->getAttribute('aria-required') === 'true') {
+			$this->setAttribute('role', 'radiogroup');
+		}
+
 		return parent::toString($destroy);
 	}
+
+	/**
+	 * Overrides base method to correctly handle autofocus attribute for radio buttons.
+	 *
+	 * @param $name
+	 * @param $value
+	 *
+	 * @return CRadioButtonList
+	 */
+	public function setAttribute($name, $value) {
+		if ($name === 'autofocus') {
+			$this->autofocused = true;
+
+			return $this;
+		}
+
+		return parent::setAttribute($name, $value);
+	}
 }
