@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2018 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -70,6 +70,9 @@ class CApiInputValidator {
 	 */
 	private static function validateData($rule, &$data, $path, &$error, array $parent_data = null) {
 		switch ($rule['type']) {
+			case API_COLOR:
+				return self::validateColor($rule, $data, $path, $error);
+
 			case API_MULTIPLE:
 				if ($parent_data !== null) {
 					return self::validateMultiple($rule, $data, $path, $error, $parent_data);
@@ -112,12 +115,21 @@ class CApiInputValidator {
 			case API_HG_NAME:
 				return self::validateHostGroupName($rule, $data, $path, $error);
 
+			case API_H_NAME:
+				return self::validateHostName($rule, $data, $path, $error);
+
+			case API_NUMERIC:
+				return self::validateNumeric($rule, $data, $path, $error);
+
 			case API_SCRIPT_NAME:
 				return self::validateScriptName($rule, $data, $path, $error);
 
 			case API_USER_MACRO:
 				return self::validateUserMacro($rule, $data, $path, $error);
 
+			case API_RANGE_TIME:
+				return self::validateRangeTime($rule, $data, $path, $error);
+
 			case API_TIME_PERIOD:
 				return self::validateTimePeriod($rule, $data, $path, $error);
 
@@ -155,17 +167,20 @@ class CApiInputValidator {
 	 */
 	private static function validateDataUniqueness($rule, &$data, $path, &$error) {
 		switch ($rule['type']) {
+			case API_COLOR:
 			case API_MULTIPLE:
 			case API_STRING_UTF8:
 			case API_INT32:
 			case API_ID:
 			case API_BOOLEAN:
 			case API_FLAG:
-			case API_OBJECT:
 			case API_OUTPUT:
 			case API_HG_NAME:
+			case API_H_NAME:
+			case API_NUMERIC:
 			case API_SCRIPT_NAME:
 			case API_USER_MACRO:
+			case API_RANGE_TIME:
 			case API_TIME_PERIOD:
 			case API_TIME_UNIT:
 			case API_REGEX:
@@ -174,6 +189,17 @@ class CApiInputValidator {
 			case API_URL:
 				return true;
 
+			case API_OBJECT:
+				foreach ($rule['fields'] as $field_name => $field_rule) {
+					if ($data !== null && array_key_exists($field_name, $data)) {
+						$subpath = ($path === '/' ? $path : $path.'/').$field_name;
+						if (!self::validateDataUniqueness($field_rule, $data[$field_name], $subpath, $error)) {
+							return false;
+						}
+					}
+				}
+				return true;
+
 			case API_IDS:
 			case API_STRINGS_UTF8:
 			case API_INTS32:
@@ -219,7 +245,39 @@ class CApiInputValidator {
 	}
 
 	/**
-	 * Myltiple data types validator.
+	 * Color validator.
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_NOT_EMPTY
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateColor($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (self::checkStringUtf8($flags & API_NOT_EMPTY, $data, $path, $error) === false) {
+			return false;
+		}
+
+		if (($flags & API_NOT_EMPTY) == 0 && $data === '') {
+			return true;
+		}
+
+		if (preg_match('/^[0-9a-f]{6}$/i', $data) !== 1) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path,
+				_('a hexadecimal colour code (6 symbols) is expected')
+			);
+			return false;
+		}
+
+		return true;
+	}
+
+	/**
+	 * Multiple data types validator.
 	 *
 	 * @param array  $rule
 	 * @param array  $rule['rules']
@@ -478,7 +536,7 @@ class CApiInputValidator {
 	 * Identifier validator.
 	 *
 	 * @param array  $rule
-	 * @param int    $rule['flags']   (optional) API_ALLOW_NULL
+	 * @param int    $rule['flags']   (optional) API_ALLOW_NULL, API_NOT_EMPTY
 	 * @param mixed  $data
 	 * @param string $path
 	 * @param string $error
@@ -497,6 +555,11 @@ class CApiInputValidator {
 			return false;
 		}
 
+		if (($flags & API_NOT_EMPTY) && $data == 0) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('cannot be empty'));
+			return false;
+		}
+
 		if (bccomp($data, '9223372036854775807') > 0) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
@@ -563,10 +626,11 @@ class CApiInputValidator {
 	 * Object validator.
 	 *
 	 * @param array  $rul
-	 * @param int    $rule['flags']                           (optional) API_ALLOW_NULL
+	 * @param int    $rule['flags']                                   (optional) API_ALLOW_NULL
 	 * @param array  $rule['fields']
-	 * @param int    $rule['fields'][<field_name>]['flags']   (optional) API_REQUIRED, API_DEPRECATED
-	 * @param mixed  $rule['fields'][<field_name>]['default'] (optional)
+	 * @param int    $rule['fields'][<field_name>]['flags']           (optional) API_REQUIRED, API_DEPRECATED
+	 * @param mixed  $rule['fields'][<field_name>]['default']         (optional)
+	 * @param string $rule['fields'][<field_name>]['default_source']  (optional)
 	 * @param mixed  $data
 	 * @param string $path
 	 * @param string $error
@@ -601,6 +665,10 @@ class CApiInputValidator {
 				$data[$field_name] = $field_rule['default'];
 			}
 
+			if (array_key_exists('default_source', $field_rule) && !array_key_exists($field_name, $data)) {
+				$data[$field_name] = $data[$field_rule['default_source']];
+			}
+
 			if (array_key_exists($field_name, $data)) {
 				$subpath = ($path === '/' ? $path : $path.'/').$field_name;
 				if (!self::validateData($field_rule, $data[$field_name], $subpath, $error, $data)) {
@@ -761,6 +829,7 @@ class CApiInputValidator {
 	 * Host group name validator.
 	 *
 	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_REQUIRED_LLD_MACRO
 	 * @param int    $rule['length']  (optional)
 	 * @param mixed  $data
 	 * @param string $path
@@ -775,16 +844,125 @@ class CApiInputValidator {
 
 		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+
 			return false;
 		}
 
-		$host_group_name_validator = new CHostGroupNameValidator();
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+		$host_group_name_parser = new CHostGroupNameParser(['lldmacros' => ($flags & API_REQUIRED_LLD_MACRO)]);
+
+		if ($host_group_name_parser->parse($data) != CParser::PARSE_SUCCESS) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('invalid host group name'));
 
-		if (!$host_group_name_validator->validate($data)) {
-			$error = _s('Invalid parameter "%1$s": %2$s.', $path, $host_group_name_validator->getError());
 			return false;
 		}
 
+		if (($flags & API_REQUIRED_LLD_MACRO) && !$host_group_name_parser->getMacros()) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path,
+				_('must contain at least one low-level discovery macro')
+			);
+
+			return false;
+		}
+
+		return true;
+	}
+
+	/**
+	 * Host name validator.
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_REQUIRED_LLD_MACRO
+	 * @param int    $rule['length']  (optional)
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateHostName($rule, &$data, $path, &$error) {
+		if (self::checkStringUtf8(API_NOT_EMPTY, $data, $path, $error) === false) {
+			return false;
+		}
+
+		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+
+			return false;
+		}
+
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+		$host_name_parser = new CHostNameParser(['lldmacros' => ($flags & API_REQUIRED_LLD_MACRO)]);
+
+		// For example, host prototype name MUST contain macros.
+		if ($host_name_parser->parse($data) != CParser::PARSE_SUCCESS) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('invalid host name'));
+
+			return false;
+		}
+
+		if (($flags & API_REQUIRED_LLD_MACRO) && !$host_name_parser->getMacros()) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path,
+				_('must contain at least one low-level discovery macro')
+			);
+
+			return false;
+		}
+
+		return true;
+	}
+
+	/**
+	 * Validator for numeric data with optional suffix.
+	 * Supported time suffixes: s, m, h, d, w
+	 * Supported metric suffixes: K, M, G, T
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['flags']   (optional) API_NOT_EMPTY
+	 * @param int    $rule['length']  (optional)
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateNumeric($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (is_int($data)) {
+			$data = (string) $data;
+		}
+
+		if (self::checkStringUtf8($flags & API_NOT_EMPTY, $data, $path, $error) === false) {
+			return false;
+		}
+
+		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+			return false;
+		}
+
+		if (($flags & API_NOT_EMPTY) == 0 && $data === '') {
+			return true;
+		}
+
+		$pattern = '/^(-?)0*(0|[1-9][0-9]*)(\.?[0-9]+)?(['.ZBX_BYTE_SUFFIXES.ZBX_TIME_SUFFIXES.'])?$/';
+
+		if (1 != preg_match($pattern, strval($data))) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is expected'));
+			return false;
+		}
+
+		$value = convertFunctionValue($data, ZBX_UNITS_ROUNDOFF_LOWER_LIMIT);
+
+		if (bccomp($value, ZBX_MIN_INT64) < 0 || bccomp($value, ZBX_MAX_INT64) > 0) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
+			return false;
+		}
+
+		// Trim leading zeroes.
+		$data = preg_replace($pattern, '${1}${2}${3}${4}', (string) $data);
+
 		return true;
 	}
 
@@ -852,6 +1030,39 @@ class CApiInputValidator {
 		return true;
 	}
 
+	/**
+	 * Time period validator like "1-7,00:00-24:00".
+	 *
+	 * @param array  $rule
+	 * @param int    $rule['length']  (optional)
+	 * @param mixed  $data
+	 * @param string $path
+	 * @param string $error
+	 *
+	 * @return bool
+	 */
+	private static function validateRangeTime($rule, &$data, $path, &$error) {
+		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
+
+		if (self::checkStringUtf8(API_NOT_EMPTY, $data, $path, $error) === false) {
+			return false;
+		}
+
+		if (array_key_exists('length', $rule) && mb_strlen($data) > $rule['length']) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('value is too long'));
+			return false;
+		}
+
+		$range_time_parser = new CRangeTimeParser();
+
+		if ($range_time_parser->parse($data) != CParser::PARSE_SUCCESS) {
+			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a time range is expected'));
+			return false;
+		}
+
+		return true;
+	}
+
 	/**
 	 * Time period validator like "1-7,00:00-24:00".
 	 *
@@ -914,7 +1125,7 @@ class CApiInputValidator {
 			return true;
 		}
 
-		if (false === @preg_match('/'.$data.'/', '')) {
+		if (@preg_match('/'.str_replace('/', '\/', $data).'/', '') === false) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('invalid regular expression'));
 			return false;
 		}
@@ -926,7 +1137,7 @@ class CApiInputValidator {
 	 * Time unit validator like "10", "20s", "30m", "4h", "{$TIME}" etc.
 	 *
 	 * @param array  $rule
-	 * @param int    $rule['flags']   (optional) API_ALLOW_USER_MACRO
+	 * @param int    $rule['flags']   (optional) API_NOT_EMPTY, API_ALLOW_USER_MACRO, API_ALLOW_LLD_MACRO
 	 * @param int    $rule['in']      (optional)
 	 * @param mixed  $data
 	 * @param string $path
@@ -945,24 +1156,32 @@ class CApiInputValidator {
 			$data = (string) $data;
 		}
 
-		if (self::checkStringUtf8(API_NOT_EMPTY, $data, $path, $error) === false) {
+		if (self::checkStringUtf8($flags & API_NOT_EMPTY, $data, $path, $error) === false) {
 			return false;
 		}
 
-		$simple_interval_parser = new CSimpleIntervalParser(['usermacros' => ($flags & API_ALLOW_USER_MACRO)]);
+		if (($flags & API_NOT_EMPTY) == 0 && $data === '') {
+			return true;
+		}
+
+		$simple_interval_parser = new CSimpleIntervalParser([
+			'usermacros' => ($flags & API_ALLOW_USER_MACRO),
+			'lldmacros' => ($flags & API_ALLOW_LLD_MACRO),
+			'negative' => true
+		]);
 
 		if ($simple_interval_parser->parse($data) != CParser::PARSE_SUCCESS) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a time unit is expected'));
 			return false;
 		}
 
-		if (($flags & API_ALLOW_USER_MACRO) && $data[0] === '{') {
+		if (($flags & (API_ALLOW_USER_MACRO | API_ALLOW_LLD_MACRO)) && $data[0] === '{') {
 			return true;
 		}
 
 		$seconds = timeUnitToSeconds($data);
 
-		if (bccomp($seconds, ZBX_MAX_INT32) > 0) {
+		if (bccomp(ZBX_MIN_INT32, $seconds) > 0 || bccomp($seconds, ZBX_MAX_INT32) > 0) {
 			$error = _s('Invalid parameter "%1$s": %2$s.', $path, _('a number is too large'));
 			return false;
 		}
@@ -1155,7 +1374,7 @@ class CApiInputValidator {
 	 *
 	 * @param array  $rule
 	 * @param int    $rule['length']  (optional)
-	 * @param int    $rule['flags']   (optional) API_ALLOW_USER_MACRO
+	 * @param int    $rule['flags']   (optional) API_ALLOW_USER_MACRO, API_NOT_EMPTY
 	 * @param mixed  $data
 	 * @param string $path
 	 * @param string $error
@@ -1165,7 +1384,7 @@ class CApiInputValidator {
 	private static function validateUrl($rule, &$data, $path, &$error) {
 		$flags = array_key_exists('flags', $rule) ? $rule['flags'] : 0x00;
 
-		if (self::checkStringUtf8(0x00, $data, $path, $error) === false) {
+		if (self::checkStringUtf8($flags & API_NOT_EMPTY, $data, $path, $error) === false) {
 			return false;
 		}
 
