@@ -20,23 +20,31 @@
 
 $widget = (new CWidget())
 	->setTitle(_('User groups'))
-	->setControls((new CForm('get'))
-		->cleanItems()
-		->addItem((new CList())->addItem(new CSubmit('form', _('Create user group'))))
+	->setControls((new CTag('nav', true,
+		(new CList())
+			->addItem(new CRedirectButton(_('Create user group'), (new CUrl('usergrps.php'))
+				->setArgument('form', 'create')
+				->getUrl()
+			))
+		))->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem((new CFilter('web.usergroup.filter.state'))
-		->addColumn((new CFormList())->addRow(_('Name'),
-			(new CTextBox('filter_name', $data['filter']['name']))
-				->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
-				->setAttribute('autofocus', 'autofocus')
-		))
-		->addColumn((new CFormList())->addRow(_('Status'),
-			(new CRadioButtonList('filter_users_status', (int) $data['filter']['users_status']))
-				->addValue(_('Any'), -1)
-				->addValue(_('Enabled'), GROUP_STATUS_ENABLED)
-				->addValue(_('Disabled'), GROUP_STATUS_DISABLED)
-				->setModern(true)
-		))
+	->addItem((new CFilter(new CUrl('usergrps.php')))
+		->setProfile($data['profileIdx'])
+		->setActiveTab($data['active_tab'])
+		->addFilterTab(_('Filter'), [
+			(new CFormList())->addRow(_('Name'),
+				(new CTextBox('filter_name', $data['filter']['name']))
+					->setWidth(ZBX_TEXTAREA_FILTER_SMALL_WIDTH)
+					->setAttribute('autofocus', 'autofocus')
+			),
+			(new CFormList())->addRow(_('Status'),
+				(new CRadioButtonList('filter_users_status', (int) $data['filter']['users_status']))
+					->addValue(_('Any'), -1)
+					->addValue(_('Enabled'), GROUP_STATUS_ENABLED)
+					->addValue(_('Disabled'), GROUP_STATUS_DISABLED)
+					->setModern(true)
+			)
+		])
 	);
 
 // create form
@@ -71,13 +79,6 @@ foreach ($this->data['usergroups'] as $usrgrp) {
 
 	// gui access
 	$guiAccess = user_auth_type2str($usrgrp['gui_access']);
-	$guiAccessStyle = ZBX_STYLE_LINK_ACTION.' '.ZBX_STYLE_GREEN;
-	if ($usrgrp['gui_access'] == GROUP_GUI_ACCESS_INTERNAL) {
-		$guiAccessStyle = ZBX_STYLE_LINK_ACTION.' '.ZBX_STYLE_ORANGE;
-	}
-	if ($usrgrp['gui_access'] == GROUP_GUI_ACCESS_DISABLED) {
-		$guiAccessStyle = ZBX_STYLE_LINK_ACTION.' '.ZBX_STYLE_RED;
-	}
 
 	if (granted2update_group($userGroupId)) {
 		$nextGuiAuth = ($usrgrp['gui_access'] + 1 > GROUP_GUI_ACCESS_DISABLED)
@@ -88,7 +89,7 @@ foreach ($this->data['usergroups'] as $usrgrp) {
 			$guiAccess,
 			'usergrps.php?action=usergroup.set_gui_access&set_gui_access='.$nextGuiAuth.'&usrgrpid='.$userGroupId
 		))
-			->addClass($guiAccessStyle)
+			->addClass(ZBX_STYLE_LINK_ACTION)
 			->addSID();
 
 		$usersStatus = ($usrgrp['users_status'] == GROUP_STATUS_ENABLED)
@@ -102,12 +103,22 @@ foreach ($this->data['usergroups'] as $usrgrp) {
 				->addSID();
 	}
 	else {
-		$guiAccess = (new CSpan($guiAccess))->addClass($guiAccessStyle);
+		$guiAccess = new CSpan($guiAccess);
 		$usersStatus = ($usrgrp['users_status'] == GROUP_STATUS_ENABLED)
 			? (new CSpan(_('Enabled')))->addClass(ZBX_STYLE_GREEN)
 			: (new CSpan(_('Disabled')))->addClass(ZBX_STYLE_RED);
 	}
 
+	if ($usrgrp['gui_access'] == GROUP_GUI_ACCESS_INTERNAL) {
+		$guiAccess->addClass(ZBX_STYLE_ORANGE);
+	}
+	elseif ($usrgrp['gui_access'] == GROUP_GUI_ACCESS_DISABLED) {
+		$guiAccess->addClass(ZBX_STYLE_RED);
+	}
+	else {
+		$guiAccess->addClass(ZBX_STYLE_GREEN);
+	}
+
 	if (isset($usrgrp['users'])) {
 		$userGroupUsers = $usrgrp['users'];
 		order_result($userGroupUsers, 'alias');
